package com.bolour.sample.eclipse.demo;

import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.core.runtime.IExtension;

/**
 * Extension-point member-processing implementation class to print 
 * identifying information about a member.
 * 
 * @author Azad
 */
public class PrintMemberIdentity implements IProcessMember {

	private static final String ACTION_SETS_EXTENSION_POINT = "org.eclipse.ui.actionSets";
	private static final String DEFAULT_LABEL_ATTRIBUTE = "label";

	private String memberLabelAttribute = null;

	/**
	 * Constructor.
	 * @param memberLabelAttribute Name of an XML attribute of an extension member's 
	 * 			element acting as a label for that member.
	 */
	public PrintMemberIdentity(String memberLabelAttribute) {
		this.memberLabelAttribute = memberLabelAttribute;
	}

	/* (non-Javadoc)
	 * @see com.bolour.sample.eclipse.demo.IProcessMember#process(org.eclipse.core.runtime.IExtension, org.eclipse.core.runtime.IConfigurationElement)
	 */
	public Object process(IExtension extension, IConfigurationElement member) {
		// Get user-readable plugin label.
		String pluginLabel = extension.getDeclaringPluginDescriptor().getLabel();
		// Get the user-readable label of the extension member.
		String memberLabel = member.getAttribute(memberLabelAttribute);
		if (memberLabel == null) {
			memberLabel = "";
		}
		memberLabel = pluginLabel + "/" + memberLabel;
		System.out.println(memberLabel);
		return memberLabel;
	}

	/**
	 * Print identification information for each member of each extension
	 * of an extension-point.
	 * 
	 * @param extensionPoint The fully-qualified id of the extension-point.
	 * @param memberLabelAttribute Name of an XML attribute of each member to use
	 * 			as its label.
	 */
	public static void test(String extensionPoint, String memberLabelAttribute) {
		if (extensionPoint == null) {
			extensionPoint = ACTION_SETS_EXTENSION_POINT;
		}
		if (memberLabelAttribute == null) {
			memberLabelAttribute = DEFAULT_LABEL_ATTRIBUTE;
		}
		System.out.println("Extension members of " + extensionPoint + ":");
		IProcessMember processor = new PrintMemberIdentity(memberLabelAttribute);
		ProcessExtensions.process(extensionPoint, processor);
	}
}
